@@ -20,14 +20,14 @@
 package org.apache.cxf.systest.jaxrs.security.jose.jwejws;
 
 import java.net.URL;
-import java.security.Security;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import javax.ws.rs.core.Response;
+import com.fasterxml.jackson.jakarta.rs.json.JacksonJsonProvider;
 
+import jakarta.ws.rs.core.Response;
 import org.apache.cxf.jaxrs.client.WebClient;
 import org.apache.cxf.rs.security.jose.jaxrs.JweWriterInterceptor;
 import org.apache.cxf.rs.security.jose.jaxrs.JwsWriterInterceptor;
@@ -35,9 +35,7 @@ import org.apache.cxf.rs.security.jose.jws.NoneJwsSignatureProvider;
 import org.apache.cxf.systest.jaxrs.security.Book;
 import org.apache.cxf.systest.jaxrs.security.SecurityTestUtil;
 import org.apache.cxf.testutil.common.AbstractBusClientServerTestBase;
-import org.bouncycastle.jce.provider.BouncyCastleProvider;
 
-import org.junit.AfterClass;
 import org.junit.BeforeClass;
 
 import static org.junit.Assert.assertEquals;
@@ -54,19 +52,9 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
     public static void startServers() throws Exception {
         assertTrue("server did not launch correctly",
                    launchServer(BookServerAlgorithms.class, true));
-        registerBouncyCastleIfNeeded();
-    }
-
-    private static void registerBouncyCastleIfNeeded() throws Exception {
-        // Still need it for Oracle Java 7 and Java 8
-        Security.addProvider(new BouncyCastleProvider());
-    }
-
-    @AfterClass
-    public static void unregisterBouncyCastleIfNeeded() throws Exception {
-        Security.removeProvider(BouncyCastleProvider.PROVIDER_NAME);
     }
 
+   
     //
     // Encryption tests
     //
@@ -77,6 +65,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jweoaepgcm/bookstore/books";
@@ -103,6 +92,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jweoaepgcm/bookstore/books";
@@ -132,6 +122,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jweoaepgcm/bookstore/books";
@@ -157,6 +148,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jweoaepgcm/bookstore/books";
@@ -186,6 +178,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jweoaepgcm/bookstore/books";
@@ -211,6 +204,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jweoaepgcm/bookstore/books";
@@ -236,6 +230,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jwesmallkey/bookstore/books";
@@ -262,9 +257,12 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
 
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
+        List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
+
         String address = "http://localhost:" + PORT + "/jweoaepgcm/bookstore/books";
         WebClient client =
-            WebClient.create(address, List.of(), busFile.toString());
+            WebClient.create(address, providers, busFile.toString());
         client.type("application/json").accept("application/json");
 
         Map<String, Object> properties = new HashMap<>();
@@ -312,6 +310,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jwepbes/bookstore/books";
@@ -340,6 +339,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JweWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jwepbes/bookstore/books";
@@ -374,6 +374,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JwsWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jws/bookstore/books";
@@ -400,6 +401,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JwsWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jws/bookstore/books";
@@ -429,6 +431,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JwsWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jws/bookstore/books";
@@ -454,6 +457,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JwsWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jws/bookstore/books";
@@ -480,6 +484,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JwsWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jws/bookstore/books";
@@ -506,6 +511,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JwsWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jwsec/bookstore/books";
@@ -534,9 +540,12 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
 
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
+        List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
+
         String address = "http://localhost:" + PORT + "/jws/bookstore/books";
         WebClient client =
-            WebClient.create(address, List.of(), busFile.toString());
+            WebClient.create(address, providers, busFile.toString());
         client.type("application/json").accept("application/json");
 
         Map<String, Object> properties = new HashMap<>();
@@ -579,6 +588,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         providers.add(new JwsWriterInterceptor());
 
         String address = "http://localhost:" + PORT + "/jwssmallkey/bookstore/books";
@@ -606,6 +616,7 @@ public class JweJwsAlgorithmTest extends AbstractBusClientServerTestBase {
         URL busFile = JweJwsAlgorithmTest.class.getResource("client.xml");
 
         List<Object> providers = new ArrayList<>();
+        providers.add(new JacksonJsonProvider());
         JwsWriterInterceptor writerInterceptor = new JwsWriterInterceptor();
         writerInterceptor.setSignatureProvider(new NoneJwsSignatureProvider());
         providers.add(writerInterceptor);
